"""CLI entry point for huntpdf."""

import argparse
import sys


def main(argv: list[str] | None = None) -> None:
    parser = argparse.ArgumentParser(
        prog="huntpdf",
        description="Fetch PDFs of arxiv, DOI, and PubMed articles.",
    )
    parser.add_argument("query", help="URL, DOI, arXiv ID, or PubMed ID")
    args = parser.parse_args(argv)
    print(args.query)


if __name__ == "__main__":
    main()
